@@ -48,8 +48,7 @@ grouped_ttest <- function(data,
   # ================== preparing dataframe ==================
   #
   # check how many variables were entered for criterion variables vector
-  dep.vars <-
-    as.list(rlang::quo_squash(rlang::enquo(dep.vars)))
+  dep.vars <- as.list(rlang::quo_squash(rlang::enquo(dep.vars)))
   dep.vars <-
     if (length(dep.vars) == 1) {
       dep.vars
@@ -58,8 +57,7 @@ grouped_ttest <- function(data,
     }
 
   # check how many variables were entered for predictor variables vector
-  indep.vars <-
-    as.list(rlang::quo_squash(rlang::enquo(indep.vars)))
+  indep.vars <- as.list(rlang::quo_squash(rlang::enquo(indep.vars)))
   indep.vars <-
     if (length(indep.vars) == 1) {
       indep.vars
@@ -68,8 +66,7 @@ grouped_ttest <- function(data,
     }
 
   # check how many variables were entered for grouping variable vector
-  grouping.vars <-
-    as.list(rlang::quo_squash(rlang::enquo(grouping.vars)))
+  grouping.vars <- as.list(rlang::quo_squash(rlang::enquo(grouping.vars)))
   grouping.vars <-
     if (length(grouping.vars) == 1) {
       grouping.vars
@@ -81,7 +78,7 @@ grouped_ttest <- function(data,
   df <-
     dplyr::select(.data = data, !!!grouping.vars, !!!dep.vars, !!!indep.vars) %>%
     dplyr::group_by(.data = ., !!!grouping.vars) %>%
-    tidyr::nest(data = .) %>%
+    tidyr::nest(.) %>%
     dplyr::filter(.data = ., !purrr::map_lgl(.x = data, .f = is.null)) %>%
     dplyr::ungroup(x = .)
 
