@@ -79,7 +79,7 @@ grouped_wilcox <- function(data,
   df <-
     dplyr::select(.data = data, !!!grouping.vars, !!!dep.vars, !!!indep.vars) %>%
     dplyr::group_by(.data = ., !!!grouping.vars) %>%
-    tidyr::nest(data = .) %>%
+    tidyr::nest(.) %>%
     dplyr::filter(.data = ., !purrr::map_lgl(.x = data, .f = is.null)) %>%
     dplyr::ungroup(x = .)
 
