@@ -27,10 +27,13 @@
 #' @importFrom tibble as_tibble
 #' @importFrom rlang exec
 #' @importFrom tidyr drop_na
+#' @importFrom dplyr matches everything
 #'
 #' @examples
-#' # model
+#' # for reproducibility
 #' set.seed(123)
+#'
+#' # model
 #' mod <-
 #'   stats::aov(
 #'     formula = mpg ~ wt + qsec + Error(disp / am),
@@ -68,11 +71,10 @@ lm_effsize_ci <- function(object,
     aov_df$df2 <- aov_df$df[aov_df$term == "Residuals"]
   }
 
-  # cleaning up the dataframe
+  # remove NAs, which would remove the row containing Residuals
+  # (redundant at this point)
   aov_df %<>%
-    dplyr::select(.data = ., -c(base::grep(pattern = "sq", x = names(.)))) %>%
-    # remove NAs, which would remove the row containing Residuals
-    # (redundant at this point)
+    dplyr::select(.data = ., -c(grep(pattern = "sq", x = names(.)))) %>%
     dplyr::rename(.data = ., df1 = df) %>%
     tidyr::drop_na(.) %>%
     tibble::as_tibble(x = .)
@@ -96,18 +98,18 @@ lm_effsize_ci <- function(object,
 
   if (class(object)[[1]] == "aovlist") {
     if (dim(dplyr::filter(effsize_df, stratum == "Within"))[[1]] != 0L) {
-      effsize_df %<>%
-        dplyr::filter(.data = ., stratum == "Within")
+      effsize_df %<>% dplyr::filter(.data = ., stratum == "Within")
     }
   }
 
   # combining the dataframes
   # merge the two preceding pieces of information by the common element of Effect
-  combined_df <- dplyr::left_join(
-    x = aov_df,
-    y = effsize_df,
-    by = "term"
-  ) %>% # reordering columns
+  combined_df <-
+    dplyr::left_join(
+      x = aov_df,
+      y = effsize_df,
+      by = "term"
+    ) %>% # reordering columns
     dplyr::select(
       .data = .,
       term,
@@ -121,7 +123,7 @@ lm_effsize_ci <- function(object,
   # in case of within-subjects design, the stratum columns will be unnecessarily added
   if ("stratum.x" %in% names(combined_df)) {
     combined_df %<>%
-      dplyr::select(.data = ., -c(base::grep(pattern = "stratum", x = names(.)))) %>%
+      dplyr::select(.data = ., -c(grep(pattern = "stratum", x = names(.)))) %>%
       dplyr::mutate(.data = ., stratum = "Within")
   }
 
@@ -129,7 +131,6 @@ lm_effsize_ci <- function(object,
   return(combined_df)
 }
 
-
 #' @title Standardize a dataframe with effect sizes for `aov`, `lm`, `aovlist`,
 #'   etc. objects.
 #' @description The difference between `lm_effsize_ci` and
@@ -141,16 +142,14 @@ lm_effsize_ci <- function(object,
 #' @inheritParams lm_effsize_ci
 #'
 #' @examples
-#' \dontrun{
+#' set.seed(123)
 #' groupedstats::lm_effsize_standardizer(
 #'   object = stats::lm(formula = brainwt ~ vore, data = ggplot2::msleep),
 #'   effsize = "eta",
 #'   partial = FALSE,
 #'   conf.level = 0.99,
-#'   nboot = 50
+#'   nboot = 20
 #' )
-#' }
-#'
 #' @export
 
 # function body
@@ -162,38 +161,13 @@ lm_effsize_standardizer <- function(object,
                                     method = c("dist", "quantile")) {
 
   # creating a dataframe with effect size and its CI
-  df <- groupedstats::lm_effsize_ci(
+  groupedstats::lm_effsize_ci(
     object = object,
     effsize = effsize,
     partial = partial,
     conf.level = conf.level,
     nboot = nboot,
     method = method
-  )
-
-  # renaming the particular effect size to standard term 'estimate'
-  if (effsize == "eta") {
-    # partial eta-squared
-    if (isTRUE(partial)) {
-      df %<>%
-        dplyr::rename(.data = ., estimate = partial.etasq)
-    } else {
-      # eta-squared
-      df %<>%
-        dplyr::rename(.data = ., estimate = etasq)
-    }
-  } else if (effsize == "omega") {
-    # partial omega-squared
-    if (isTRUE(partial)) {
-      df %<>%
-        dplyr::rename(.data = ., estimate = partial.omegasq)
-    } else {
-      # omega-squared
-      df %<>%
-        dplyr::rename(.data = ., estimate = omegasq)
-    }
-  }
-
-  # return the dataframe in standard format
-  return(df)
+  ) %>% # renaming the effect size to standard term 'estimate'
+    dplyr::rename(.data = ., estimate = dplyr::matches("etasq$|omegasq$"))
 }
