@@ -25,3 +25,7 @@ magrittr::`%<>%`
 #' @export
 #' @importFrom magrittr "%$%"
 magrittr::`%$%`
+
+#' @export
+#' @importFrom tibble tibble
+tibble::tibble
